@@ -234,8 +234,7 @@ class TestListAudit(api_base.FunctionalTest):
         self.assertIn(next_marker, response['next'])
 
     def test_collection_links_default_limit(self):
-        cfg.CONF.set_override('max_limit', 3, 'api',
-                              enforce_type=True)
+        cfg.CONF.set_override('max_limit', 3, 'api')
         for id_ in range(5):
             obj_utils.create_test_audit(self.context, id=id_,
                                         uuid=utils.generate_uuid())
@@ -345,23 +344,10 @@ class TestPatch(api_base.FunctionalTest):
 
 
 ALLOWED_TRANSITIONS = [
-    {"original_state": objects.audit.State.PENDING,
-     "new_state": objects.audit.State.ONGOING},
-    {"original_state": objects.audit.State.PENDING,
-     "new_state": objects.audit.State.CANCELLED},
-    {"original_state": objects.audit.State.ONGOING,
-     "new_state": objects.audit.State.FAILED},
-    {"original_state": objects.audit.State.ONGOING,
-     "new_state": objects.audit.State.SUCCEEDED},
-    {"original_state": objects.audit.State.ONGOING,
-     "new_state": objects.audit.State.CANCELLED},
-    {"original_state": objects.audit.State.FAILED,
-     "new_state": objects.audit.State.DELETED},
-    {"original_state": objects.audit.State.SUCCEEDED,
-     "new_state": objects.audit.State.DELETED},
-    {"original_state": objects.audit.State.CANCELLED,
-     "new_state": objects.audit.State.DELETED},
-]
+    {"original_state": key, "new_state": value}
+    for key, values in (
+        objects.audit.AuditStateTransitionManager.TRANSITIONS.items())
+    for value in values]
 
 
 class TestPatchStateTransitionDenied(api_base.FunctionalTest):
